@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 import logging
 
 import pydbus
@@ -8,11 +6,10 @@ from mopidy_mpris.player import Player
 from mopidy_mpris.playlists import Playlists
 from mopidy_mpris.root import Root
 
-
 logger = logging.getLogger(__name__)
 
 
-class Server(object):
+class Server:
     def __init__(self, config, core):
         self.config = config
         self.core = core
@@ -24,21 +21,21 @@ class Server(object):
         self._publication_token = None
 
     def publish(self):
-        bus_type = self.config['mpris']['bus_type']
-        logger.debug('Connecting to D-Bus %s bus...', bus_type)
+        bus_type = self.config["mpris"]["bus_type"]
+        logger.debug("Connecting to D-Bus %s bus...", bus_type)
 
-        if bus_type == 'system':
+        if bus_type == "system":
             bus = pydbus.SystemBus()
         else:
             bus = pydbus.SessionBus()
 
-        logger.info('MPRIS server connected to D-Bus %s bus', bus_type)
+        logger.info("MPRIS server connected to D-Bus %s bus", bus_type)
 
         self._publication_token = bus.publish(
-            'org.mpris.MediaPlayer2.mopidy',
-            ('/org/mpris/MediaPlayer2', self.root),
-            ('/org/mpris/MediaPlayer2', self.player),
-            ('/org/mpris/MediaPlayer2', self.playlists),
+            "org.mpris.MediaPlayer2.mopidy",
+            ("/org/mpris/MediaPlayer2", self.root),
+            ("/org/mpris/MediaPlayer2", self.player),
+            ("/org/mpris/MediaPlayer2", self.playlists),
         )
 
     def unpublish(self):
