@@ -1,15 +1,10 @@
-from __future__ import unicode_literals
-
+import pytest
 from gi.repository import GLib
 
 from mopidy.core import PlaybackState
 from mopidy.models import Album, Artist, Image, Track
-
-import pytest
-
 from mopidy_mpris.player import Player
 
-
 PLAYING = PlaybackState.PLAYING
 PAUSED = PlaybackState.PAUSED
 STOPPED = PlaybackState.STOPPED
@@ -20,23 +15,25 @@ def player(config, core):
     return Player(config, core)
 
 
-@pytest.mark.parametrize('state, expected', [
-    (PLAYING, 'Playing'),
-    (PAUSED, 'Paused'),
-    (STOPPED, 'Stopped'),
-])
+@pytest.mark.parametrize(
+    "state, expected",
+    [(PLAYING, "Playing"), (PAUSED, "Paused"), (STOPPED, "Stopped")],
+)
 def test_get_playback_status(core, player, state, expected):
     core.playback.set_state(state)
 
     assert player.PlaybackStatus == expected
 
 
-@pytest.mark.parametrize('repeat, single, expected', [
-    (False, False, 'None'),
-    (False, True, 'None'),
-    (True, False, 'Playlist'),
-    (True, True, 'Track'),
-])
+@pytest.mark.parametrize(
+    "repeat, single, expected",
+    [
+        (False, False, "None"),
+        (False, True, "None"),
+        (True, False, "Playlist"),
+        (True, True, "Track"),
+    ],
+)
 def test_get_loop_status(core, player, repeat, single, expected):
     core.tracklist.set_repeat(repeat)
     core.tracklist.set_single(single)
@@ -44,13 +41,13 @@ def test_get_loop_status(core, player, repeat, single, expected):
     assert player.LoopStatus == expected
 
 
-@pytest.mark.parametrize('status, expected_repeat, expected_single', [
-    ('None', False, False),
-    ('Track', True, True),
-    ('Playlist', True, False),
-])
+@pytest.mark.parametrize(
+    "status, expected_repeat, expected_single",
+    [("None", False, False), ("Track", True, True), ("Playlist", True, False)],
+)
 def test_set_loop_status(
-        core, player, status, expected_repeat, expected_single):
+    core, player, status, expected_repeat, expected_single
+):
     player.LoopStatus = status
 
     assert core.tracklist.get_repeat().get() is expected_repeat
@@ -62,7 +59,7 @@ def test_set_loop_status_is_ignored_if_can_control_is_false(core, player):
     core.tracklist.set_repeat(True)
     core.tracklist.set_single(True)
 
-    player.LoopStatus = 'None'
+    player.LoopStatus = "None"
 
     assert core.tracklist.get_repeat().get() is True
     assert core.tracklist.get_single().get() is True
@@ -77,7 +74,7 @@ def test_get_rate_is_less_or_equal_than_maximum_rate(player):
 
 
 def test_set_rate_to_zero_pauses_playback(core, player):
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     assert core.playback.get_state().get() == PLAYING
 
@@ -88,7 +85,7 @@ def test_set_rate_to_zero_pauses_playback(core, player):
 
 def test_set_rate_is_ignored_if_can_control_is_false(core, player):
     player._CanControl = False
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     assert core.playback.get_state().get() == PLAYING
 
@@ -97,14 +94,14 @@ def test_set_rate_is_ignored_if_can_control_is_false(core, player):
     assert core.playback.get_state().get() == PLAYING
 
 
-@pytest.mark.parametrize('random', [True, False])
+@pytest.mark.parametrize("random", [True, False])
 def test_get_shuffle(core, player, random):
     core.tracklist.set_random(random)
 
     assert player.Shuffle is random
 
 
-@pytest.mark.parametrize('value', [True, False])
+@pytest.mark.parametrize("value", [True, False])
 def test_set_shuffle(core, player, value):
     core.tracklist.set_random(not value)
     assert core.tracklist.get_random().get() is not value
@@ -128,114 +125,85 @@ def test_get_metadata_is_empty_when_no_current_track(player):
 
 
 def test_get_metadata(core, player):
-    core.tracklist.add([Track(
-        uri='dummy:a',
-        length=3600000,
-        name='a',
-        artists=[Artist(name='b'), Artist(name='c'), Artist(name=None)],
-        album=Album(
-            name='d',
-            artists=[Artist(name='e'), Artist(name=None)],
-        ),
-    )])
+    core.tracklist.add(
+        [
+            Track(
+                uri="dummy:a",
+                length=3600000,
+                name="a",
+                artists=[Artist(name="b"), Artist(name="c"), Artist(name=None)],
+                album=Album(
+                    name="d", artists=[Artist(name="e"), Artist(name=None)],
+                ),
+            )
+        ]
+    )
     core.playback.play().get()
 
     (tlid, track) = core.playback.get_current_tl_track().get()
 
     result = player.Metadata
 
-    assert result['mpris:trackid'] == GLib.Variant(
-        'o', '/com/mopidy/track/%d' % tlid)
-    assert result['mpris:length'] == GLib.Variant('x', 3600000000)
-    assert result['xesam:url'] == GLib.Variant('s', 'dummy:a')
-    assert result['xesam:title'] == GLib.Variant('s', 'a')
-    assert result['xesam:artist'] == GLib.Variant('as', ['b', 'c'])
-    assert result['xesam:album'] == GLib.Variant('s', 'd')
-    assert result['xesam:albumArtist'] == GLib.Variant('as', ['e'])
+    assert result["mpris:trackid"] == GLib.Variant(
+        "o", "/com/mopidy/track/%d" % tlid
+    )
+    assert result["mpris:length"] == GLib.Variant("x", 3600000000)
+    assert result["xesam:url"] == GLib.Variant("s", "dummy:a")
+    assert result["xesam:title"] == GLib.Variant("s", "a")
+    assert result["xesam:artist"] == GLib.Variant("as", ["b", "c"])
+    assert result["xesam:album"] == GLib.Variant("s", "d")
+    assert result["xesam:albumArtist"] == GLib.Variant("as", ["e"])
 
 
-def test_get_metadata_prefers_stream_title_over_track_name(
-        audio, core, player):
-    core.tracklist.add([Track(
-        uri='dummy:a',
-        name='Track name',
-    )])
+def test_get_metadata_prefers_stream_title_over_track_name(audio, core, player):
+    core.tracklist.add([Track(uri="dummy:a", name="Track name",)])
     core.playback.play().get()
 
     result = player.Metadata
-    assert result['xesam:title'] == GLib.Variant('s', 'Track name')
+    assert result["xesam:title"] == GLib.Variant("s", "Track name")
 
-    audio.trigger_fake_tags_changed({
-        'organization': ['Required for Mopidy core to care about the title'],
-        'title': ['Stream title'],
-    }).get()
+    audio.trigger_fake_tags_changed(
+        {
+            "organization": [
+                "Required for Mopidy core to care about the title"
+            ],
+            "title": ["Stream title"],
+        }
+    ).get()
 
     result = player.Metadata
-    assert result['xesam:title'] == GLib.Variant('s', 'Stream title')
-
-
-def test_get_metadata_use_first_album_image_as_art_url(core, player):
-    # XXX Currently, the album image order isn't preserved because they
-    # are stored as a frozenset(). We pick the first in the set, which is
-    # sorted alphabetically, thus we get 'bar.jpg', not 'foo.jpg', which
-    # would probably make more sense.
-    core.tracklist.add([Track(
-        uri='dummy:a',
-        album=Album(images=[
-            'http://example.com/foo.jpg',
-            'http://example.com/bar.jpg',
-        ]),
-    )])
-    core.playback.play().get()
-
-    result = player.Metadata
-
-    assert result['mpris:artUrl'] == GLib.Variant(
-        's', 'http://example.com/bar.jpg')
+    assert result["xesam:title"] == GLib.Variant("s", "Stream title")
 
 
 def test_get_metadata_use_library_image_as_art_url(backend, core, player):
     backend.library.dummy_get_images_result = {
-        'dummy:a': [
-            Image(uri='http://example.com/small.jpg', width=100, height=100),
-            Image(uri='http://example.com/large.jpg', width=200, height=200),
+        "dummy:a": [
+            Image(uri="http://example.com/small.jpg", width=100, height=100),
+            Image(uri="http://example.com/large.jpg", width=200, height=200),
         ],
     }
-    core.tracklist.add([Track(uri='dummy:a')])
+    core.tracklist.add([Track(uri="dummy:a")])
     core.playback.play().get()
 
     result = player.Metadata
 
-    assert result['mpris:artUrl'] == GLib.Variant(
-        's', 'http://example.com/large.jpg')
-
-
-def test_get_metadata_has_no_art_url_if_no_album(core, player):
-    core.tracklist.add([Track(uri='dummy:a')])
-    core.playback.play().get()
-
-    assert 'mpris:artUrl' not in player.Metadata
-
-
-def test_get_metadata_has_no_art_url_if_no_album_images(core, player):
-    core.tracklist.add([Track(uri='dummy:a', album=Album(images=[]))])
-    core.playback.play().get()
-
-    assert 'mpris:artUrl' not in player.Metadata
+    assert result["mpris:artUrl"] == GLib.Variant(
+        "s", "http://example.com/large.jpg"
+    )
 
 
 def test_get_metadata_has_disc_number_in_album(core, player):
-    core.tracklist.add([Track(uri='dummy:a', disc_no=2)])
+    core.tracklist.add([Track(uri="dummy:a", disc_no=2)])
     core.playback.play().get()
 
-    assert player.Metadata['xesam:discNumber'] == GLib.Variant('i', 2)
+    assert player.Metadata["xesam:discNumber"] == GLib.Variant("i", 2)
 
 
 def test_get_metadata_has_track_number_in_album(core, player):
-    core.tracklist.add([Track(uri='dummy:a', track_no=7)])
+    core.tracklist.add([Track(uri="dummy:a", track_no=7)])
     core.playback.play().get()
 
-    assert player.Metadata['xesam:trackNumber'] == GLib.Variant('i', 7)
+    assert player.Metadata["xesam:trackNumber"] == GLib.Variant("i", 7)
 
 
 def test_get_volume_should_return_volume_between_zero_and_one(core, player):
@@ -265,13 +233,9 @@ def test_get_volume_should_return_0_if_muted(core, player):
     assert player.Volume == 1
 
 
-@pytest.mark.parametrize('volume, expected', [
-    (-1.0, 0),
-    (0, 0),
-    (0.5, 50),
-    (1.0, 100),
-    (2.0, 100),
-])
+@pytest.mark.parametrize(
+    "volume, expected", [(-1.0, 0), (0, 0), (0.5, 50), (1.0, 100), (2.0, 100)]
+)
 def test_set_volume(core, player, volume, expected):
     player.Volume = volume
 
@@ -316,7 +280,7 @@ def test_set_volume_to_zero_does_not_unmute_if_muted(core, player):
 
 
 def test_get_position_returns_time_position_in_microseconds(core, player):
-    core.tracklist.add([Track(uri='dummy:a', length=40000)])
+    core.tracklist.add([Track(uri="dummy:a", length=40000)])
     core.playback.play().get()
     core.playback.seek(10000).get()
 
@@ -343,7 +307,7 @@ def test_get_maximum_rate_is_one_or_more(player):
 
 def test_can_go_next_is_true_if_can_control_and_other_next_track(core, player):
     player._CanControl = True
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
 
     assert player.CanGoNext
@@ -351,7 +315,7 @@ def test_can_go_next_is_true_if_can_control_and_other_next_track(core, player):
 
 def test_can_go_next_is_false_if_next_track_is_the_same(core, player):
     player._CanControl = True
-    core.tracklist.add([Track(uri='dummy:a')])
+    core.tracklist.add([Track(uri="dummy:a")])
     core.tracklist.set_repeat(True)
     core.playback.play().get()
 
@@ -360,16 +324,17 @@ def test_can_go_next_is_false_if_next_track_is_the_same(core, player):
 
 def test_can_go_next_is_false_if_can_control_is_false(core, player):
     player._CanControl = False
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
 
     assert not player.CanGoNext
 
 
 def test_can_go_previous_is_true_if_can_control_and_previous_track(
-        core, player):
+    core, player
+):
     player._CanControl = True
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     core.playback.next().get()
 
@@ -378,7 +343,7 @@ def test_can_go_previous_is_true_if_can_control_and_previous_track(
 
 def test_can_go_previous_is_false_if_previous_track_is_the_same(core, player):
     player._CanControl = True
-    core.tracklist.add([Track(uri='dummy:a')])
+    core.tracklist.add([Track(uri="dummy:a")])
     core.tracklist.set_repeat(True)
     core.playback.play().get()
 
@@ -387,7 +352,7 @@ def test_can_go_previous_is_false_if_previous_track_is_the_same(core, player):
 
 def test_can_go_previous_is_false_if_can_control_is_false(core, player):
     player._CanControl = False
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     core.playback.next().get()
 
@@ -396,7 +361,7 @@ def test_can_go_previous_is_false_if_can_control_is_false(core, player):
 
 def test_can_play_is_true_if_can_control_and_current_track(core, player):
     player._CanControl = True
-    core.tracklist.add([Track(uri='dummy:a')])
+    core.tracklist.add([Track(uri="dummy:a")])
     core.playback.play().get()
     assert core.playback.get_current_track().get()
 
@@ -416,8 +381,7 @@ def test_can_play_if_false_if_can_control_is_false(core, player):
     assert not player.CanPlay
 
 
-def test_can_pause_is_true_if_can_control_and_track_can_be_paused(
-        core, player):
+def test_can_pause_is_true_if_can_control_and_track_can_be_paused(core, player):
     player._CanControl = True
 
     assert player.CanPause
@@ -449,91 +413,93 @@ def test_can_control_is_true(core, player):
 def test_next_is_ignored_if_can_go_next_is_false(core, player):
     player._CanControl = False
     assert not player.CanGoNext
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
-    assert core.playback.get_current_track().get().uri == 'dummy:a'
+    assert core.playback.get_current_track().get().uri == "dummy:a"
 
     player.Next()
 
-    assert core.playback.get_current_track().get().uri == 'dummy:a'
+    assert core.playback.get_current_track().get().uri == "dummy:a"
 
 
 def test_next_when_playing_skips_to_next_track_and_keep_playing(core, player):
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
-    assert core.playback.get_current_track().get().uri == 'dummy:a'
+    assert core.playback.get_current_track().get().uri == "dummy:a"
     assert core.playback.get_state().get() == PLAYING
 
     player.Next()
 
-    assert core.playback.get_current_track().get().uri == 'dummy:b'
+    assert core.playback.get_current_track().get().uri == "dummy:b"
     assert core.playback.get_state().get() == PLAYING
 
 
 def test_next_when_at_end_of_list_should_stop_playback(core, player):
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     core.playback.next().get()
-    assert core.playback.get_current_track().get().uri == 'dummy:b'
+    assert core.playback.get_current_track().get().uri == "dummy:b"
     assert core.playback.get_state().get() == PLAYING
     player.Next()
     assert core.playback.get_state().get() == STOPPED
 
 
 def test_next_when_paused_should_skip_to_next_track_and_stay_paused(
-        core, player):
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core, player
+):
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     core.playback.pause().get()
-    assert core.playback.get_current_track().get().uri == 'dummy:a'
+    assert core.playback.get_current_track().get().uri == "dummy:a"
     assert core.playback.get_state().get() == PAUSED
     player.Next()
-    assert core.playback.get_current_track().get().uri == 'dummy:b'
+    assert core.playback.get_current_track().get().uri == "dummy:b"
     assert core.playback.get_state().get() == PAUSED
 
 
 def test_next_when_stopped_skips_to_next_track_and_stay_stopped(core, player):
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     core.playback.stop()
-    assert core.playback.get_current_track().get().uri == 'dummy:a'
+    assert core.playback.get_current_track().get().uri == "dummy:a"
     assert core.playback.get_state().get() == STOPPED
     player.Next()
-    assert core.playback.get_current_track().get().uri == 'dummy:b'
+    assert core.playback.get_current_track().get().uri == "dummy:b"
     assert core.playback.get_state().get() == STOPPED
 
 
 def test_previous_is_ignored_if_can_go_previous_is_false(core, player):
     player._CanControl = False
     assert not player.CanGoPrevious
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     core.playback.next().get()
-    assert core.playback.get_current_track().get().uri == 'dummy:b'
+    assert core.playback.get_current_track().get().uri == "dummy:b"
 
     player.Previous()
 
-    assert core.playback.get_current_track().get().uri == 'dummy:b'
+    assert core.playback.get_current_track().get().uri == "dummy:b"
 
 
 def test_previous_when_playing_skips_to_prev_track_and_keep_playing(
-        core, player):
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core, player
+):
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     core.playback.next().get()
-    assert core.playback.get_current_track().get().uri == 'dummy:b'
+    assert core.playback.get_current_track().get().uri == "dummy:b"
     assert core.playback.get_state().get() == PLAYING
 
     player.Previous()
 
-    assert core.playback.get_current_track().get().uri == 'dummy:a'
+    assert core.playback.get_current_track().get().uri == "dummy:a"
     assert core.playback.get_state().get() == PLAYING
 
 
 def test_previous_when_at_start_of_list_should_stop_playback(core, player):
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
-    assert core.playback.get_current_track().get().uri == 'dummy:a'
+    assert core.playback.get_current_track().get().uri == "dummy:a"
     assert core.playback.get_state().get() == PLAYING
 
     player.Previous()
@@ -542,37 +508,37 @@ def test_previous_when_at_start_of_list_should_stop_playback(core, player):
 
 
 def test_previous_when_paused_skips_to_previous_track_and_pause(core, player):
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     core.playback.next().get()
     core.playback.pause().get()
-    assert core.playback.get_current_track().get().uri == 'dummy:b'
+    assert core.playback.get_current_track().get().uri == "dummy:b"
     assert core.playback.get_state().get() == PAUSED
 
     player.Previous()
 
-    assert core.playback.get_current_track().get().uri == 'dummy:a'
+    assert core.playback.get_current_track().get().uri == "dummy:a"
     assert core.playback.get_state().get() == PAUSED
 
 
 def test_previous_when_stopped_skips_to_previous_track_and_stops(core, player):
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     core.playback.next().get()
     core.playback.stop()
-    assert core.playback.get_current_track().get().uri == 'dummy:b'
+    assert core.playback.get_current_track().get().uri == "dummy:b"
     assert core.playback.get_state().get() == STOPPED
 
     player.Previous()
 
-    assert core.playback.get_current_track().get().uri == 'dummy:a'
+    assert core.playback.get_current_track().get().uri == "dummy:a"
     assert core.playback.get_state().get() == STOPPED
 
 
 def test_pause_is_ignored_if_can_pause_is_false(core, player):
     player._CanControl = False
     assert not player.CanPause
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     assert core.playback.get_state().get() == PLAYING
 
@@ -582,7 +548,7 @@ def test_pause_is_ignored_if_can_pause_is_false(core, player):
 
 
 def test_pause_when_playing_should_pause_playback(core, player):
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     assert core.playback.get_state().get() == PLAYING
 
@@ -592,7 +558,7 @@ def test_pause_when_playing_should_pause_playback(core, player):
 
 
 def test_pause_when_paused_has_no_effect(core, player):
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     core.playback.pause().get()
     assert core.playback.get_state().get() == PAUSED
@@ -605,7 +571,7 @@ def test_pause_when_paused_has_no_effect(core, player):
 def test_playpause_is_ignored_if_can_pause_is_false(core, player):
     player._CanControl = False
     assert not player.CanPause
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     assert core.playback.get_state().get() == PLAYING
 
@@ -615,7 +581,7 @@ def test_playpause_is_ignored_if_can_pause_is_false(core, player):
 
 
 def test_playpause_when_playing_should_pause_playback(core, player):
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     assert core.playback.get_state().get() == PLAYING
 
@@ -625,7 +591,7 @@ def test_playpause_when_playing_should_pause_playback(core, player):
 
 
 def test_playpause_when_paused_should_resume_playback(core, player):
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     core.playback.pause().get()
 
@@ -641,7 +607,7 @@ def test_playpause_when_paused_should_resume_playback(core, player):
 
 
 def test_playpause_when_stopped_should_start_playback(core, player):
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     assert core.playback.get_state().get() == STOPPED
 
     player.PlayPause()
@@ -651,7 +617,7 @@ def test_playpause_when_stopped_should_start_playback(core, player):
 
 def test_stop_is_ignored_if_can_control_is_false(core, player):
     player._CanControl = False
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     assert core.playback.get_state().get() == PLAYING
 
@@ -661,7 +627,7 @@ def test_stop_is_ignored_if_can_control_is_false(core, player):
 
 
 def test_stop_when_playing_should_stop_playback(core, player):
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     assert core.playback.get_state().get() == PLAYING
 
@@ -671,7 +637,7 @@ def test_stop_when_playing_should_stop_playback(core, player):
 
 
 def test_stop_when_paused_should_stop_playback(core, player):
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     core.playback.pause().get()
     assert core.playback.get_state().get() == PAUSED
@@ -684,7 +650,7 @@ def test_stop_when_paused_should_stop_playback(core, player):
 def test_play_is_ignored_if_can_play_is_false(core, player):
     player._CanControl = False
     assert not player.CanPlay
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     assert core.playback.get_state().get() == STOPPED
 
     player.Play()
@@ -693,7 +659,7 @@ def test_play_is_ignored_if_can_play_is_false(core, player):
 
 
 def test_play_when_stopped_starts_playback(core, player):
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     assert core.playback.get_state().get() == STOPPED
 
     player.Play()
@@ -702,7 +668,7 @@ def test_play_when_stopped_starts_playback(core, player):
 
 
 def test_play_after_pause_resumes_from_same_position(core, player):
-    core.tracklist.add([Track(uri='dummy:a', length=40000)])
+    core.tracklist.add([Track(uri="dummy:a", length=40000)])
     core.playback.play().get()
 
     before_pause = core.playback.get_time_position().get()
@@ -733,7 +699,7 @@ def test_play_when_there_is_no_track_has_no_effect(core, player):
 def test_seek_is_ignored_if_can_seek_is_false(core, player):
     player._CanControl = False
     assert not player.CanSeek
-    core.tracklist.add([Track(uri='dummy:a', length=40000)])
+    core.tracklist.add([Track(uri="dummy:a", length=40000)])
     core.playback.play().get()
 
     before_seek = core.playback.get_time_position().get()
@@ -750,8 +716,9 @@ def test_seek_is_ignored_if_can_seek_is_false(core, player):
 
 
 def test_seek_seeks_given_microseconds_forward_in_the_current_track(
-        core, player):
-    core.tracklist.add([Track(uri='dummy:a', length=40000)])
+    core, player
+):
+    core.tracklist.add([Track(uri="dummy:a", length=40000)])
     core.playback.play().get()
 
     before_seek = core.playback.get_time_position().get()
@@ -769,7 +736,7 @@ def test_seek_seeks_given_microseconds_forward_in_the_current_track(
 
 
 def test_seek_seeks_given_microseconds_backward_if_negative(core, player):
-    core.tracklist.add([Track(uri='dummy:a', length=40000)])
+    core.tracklist.add([Track(uri="dummy:a", length=40000)])
     core.playback.play().get()
     core.playback.seek(20000).get()
 
@@ -788,9 +755,8 @@ def test_seek_seeks_given_microseconds_backward_if_negative(core, player):
     assert after_seek < before_seek
 
 
-def test_seek_seeks_to_start_of_track_if_new_position_is_negative(
-        core, player):
-    core.tracklist.add([Track(uri='dummy:a', length=40000)])
+def test_seek_seeks_to_start_of_track_if_new_position_is_negative(core, player):
+    core.tracklist.add([Track(uri="dummy:a", length=40000)])
     core.playback.play().get()
     core.playback.seek(20000).get()
 
@@ -810,18 +776,17 @@ def test_seek_seeks_to_start_of_track_if_new_position_is_negative(
     assert after_seek >= 0
 
 
-def test_seek_skips_to_next_track_if_new_position_gt_track_length(
-        core, player):
-    core.tracklist.add([
-        Track(uri='dummy:a', length=40000),
-        Track(uri='dummy:b')])
+def test_seek_skips_to_next_track_if_new_position_gt_track_length(core, player):
+    core.tracklist.add(
+        [Track(uri="dummy:a", length=40000), Track(uri="dummy:b")]
+    )
     core.playback.play().get()
     core.playback.seek(20000).get()
 
     before_seek = core.playback.get_time_position().get()
     assert before_seek >= 20000
     assert core.playback.get_state().get() == PLAYING
-    assert core.playback.get_current_track().get().uri == 'dummy:a'
+    assert core.playback.get_current_track().get().uri == "dummy:a"
 
     milliseconds_to_seek = 50000
     microseconds_to_seek = milliseconds_to_seek * 1000
@@ -829,7 +794,7 @@ def test_seek_skips_to_next_track_if_new_position_gt_track_length(
     player.Seek(microseconds_to_seek)
 
     assert core.playback.get_state().get() == PLAYING
-    assert core.playback.get_current_track().get().uri == 'dummy:b'
+    assert core.playback.get_current_track().get().uri == "dummy:b"
 
     after_seek = core.playback.get_time_position().get()
     assert after_seek >= 0
@@ -838,13 +803,13 @@ def test_seek_skips_to_next_track_if_new_position_gt_track_length(
 
 def test_set_position_is_ignored_if_can_seek_is_false(core, player):
     player.get_CanSeek = lambda *_: False
-    core.tracklist.add([Track(uri='dummy:a', length=40000)])
+    core.tracklist.add([Track(uri="dummy:a", length=40000)])
     core.playback.play().get()
 
     before_set_position = core.playback.get_time_position().get()
     assert before_set_position <= 5000
 
-    track_id = 'a'
+    track_id = "a"
 
     position_to_set_in_millisec = 20000
     position_to_set_in_microsec = position_to_set_in_millisec * 1000
@@ -857,15 +822,16 @@ def test_set_position_is_ignored_if_can_seek_is_false(core, player):
 
 
 def test_set_position_sets_the_current_track_position_in_microsecs(
-        core, player):
-    core.tracklist.add([Track(uri='dummy:a', length=40000)])
+    core, player
+):
+    core.tracklist.add([Track(uri="dummy:a", length=40000)])
     core.playback.play().get()
 
     before_set_position = core.playback.get_time_position().get()
     assert before_set_position <= 5000
     assert core.playback.get_state().get() == PLAYING
 
-    track_id = '/com/mopidy/track/1'
+    track_id = "/com/mopidy/track/1"
 
     position_to_set_in_millisec = 20000
     position_to_set_in_microsec = position_to_set_in_millisec * 1000
@@ -879,7 +845,7 @@ def test_set_position_sets_the_current_track_position_in_microsecs(
 
 
 def test_set_position_does_nothing_if_the_position_is_negative(core, player):
-    core.tracklist.add([Track(uri='dummy:a', length=40000)])
+    core.tracklist.add([Track(uri="dummy:a", length=40000)])
     core.playback.play().get()
     core.playback.seek(20000)
 
@@ -887,9 +853,9 @@ def test_set_position_does_nothing_if_the_position_is_negative(core, player):
     assert before_set_position >= 20000
     assert before_set_position <= 25000
     assert core.playback.get_state().get() == PLAYING
-    assert core.playback.get_current_track().get().uri == 'dummy:a'
+    assert core.playback.get_current_track().get().uri == "dummy:a"
 
-    track_id = '/com/mopidy/track/1'
+    track_id = "/com/mopidy/track/1"
 
     position_to_set_in_millisec = -1000
     position_to_set_in_microsec = position_to_set_in_millisec * 1000
@@ -899,12 +865,11 @@ def test_set_position_does_nothing_if_the_position_is_negative(core, player):
     after_set_position = core.playback.get_time_position().get()
     assert after_set_position >= before_set_position
     assert core.playback.get_state().get() == PLAYING
-    assert core.playback.get_current_track().get().uri == 'dummy:a'
+    assert core.playback.get_current_track().get().uri == "dummy:a"
 
 
-def test_set_position_does_nothing_if_position_is_gt_track_length(
-        core, player):
-    core.tracklist.add([Track(uri='dummy:a', length=40000)])
+def test_set_position_does_nothing_if_position_is_gt_track_length(core, player):
+    core.tracklist.add([Track(uri="dummy:a", length=40000)])
     core.playback.play().get()
     core.playback.seek(20000)
 
@@ -912,9 +877,9 @@ def test_set_position_does_nothing_if_position_is_gt_track_length(
     assert before_set_position >= 20000
     assert before_set_position <= 25000
     assert core.playback.get_state().get() == PLAYING
-    assert core.playback.get_current_track().get().uri == 'dummy:a'
+    assert core.playback.get_current_track().get().uri == "dummy:a"
 
-    track_id = 'a'
+    track_id = "a"
 
     position_to_set_in_millisec = 50000
     position_to_set_in_microsec = position_to_set_in_millisec * 1000
@@ -924,11 +889,11 @@ def test_set_position_does_nothing_if_position_is_gt_track_length(
     after_set_position = core.playback.get_time_position().get()
     assert after_set_position >= before_set_position
     assert core.playback.get_state().get() == PLAYING
-    assert core.playback.get_current_track().get().uri == 'dummy:a'
+    assert core.playback.get_current_track().get().uri == "dummy:a"
 
 
 def test_set_position_is_noop_if_track_id_isnt_current_track(core, player):
-    core.tracklist.add([Track(uri='dummy:a', length=40000)])
+    core.tracklist.add([Track(uri="dummy:a", length=40000)])
     core.playback.play().get()
     core.playback.seek(20000)
 
@@ -936,9 +901,9 @@ def test_set_position_is_noop_if_track_id_isnt_current_track(core, player):
     assert before_set_position >= 20000
     assert before_set_position <= 25000
     assert core.playback.get_state().get() == PLAYING
-    assert core.playback.get_current_track().get().uri == 'dummy:a'
+    assert core.playback.get_current_track().get().uri == "dummy:a"
 
-    track_id = 'b'
+    track_id = "b"
 
     position_to_set_in_millisec = 0
     position_to_set_in_microsec = position_to_set_in_millisec * 1000
@@ -948,73 +913,73 @@ def test_set_position_is_noop_if_track_id_isnt_current_track(core, player):
     after_set_position = core.playback.get_time_position().get()
     assert after_set_position >= before_set_position
     assert core.playback.get_state().get() == PLAYING
-    assert core.playback.get_current_track().get().uri == 'dummy:a'
+    assert core.playback.get_current_track().get().uri == "dummy:a"
 
 
 def test_open_uri_is_ignored_if_can_control_is_false(backend, core, player):
     player._CanControl = False
-    backend.library.dummy_library = [
-        Track(uri='dummy:/test/uri')]
+    backend.library.dummy_library = [Track(uri="dummy:/test/uri")]
 
-    player.OpenUri('dummy:/test/uri')
+    player.OpenUri("dummy:/test/uri")
 
     assert core.tracklist.get_length().get() == 0
 
 
 def test_open_uri_ignores_uris_with_unknown_uri_scheme(backend, core, player):
-    assert core.get_uri_schemes().get() == ['dummy']
-    backend.library.dummy_library = [Track(uri='notdummy:/test/uri')]
+    assert core.get_uri_schemes().get() == ["dummy"]
+    backend.library.dummy_library = [Track(uri="notdummy:/test/uri")]
 
-    player.OpenUri('notdummy:/test/uri')
+    player.OpenUri("notdummy:/test/uri")
 
     assert core.tracklist.get_length().get() == 0
 
 
 def test_open_uri_adds_uri_to_tracklist(backend, core, player):
-    backend.library.dummy_library = [Track(uri='dummy:/test/uri')]
+    backend.library.dummy_library = [Track(uri="dummy:/test/uri")]
 
-    player.OpenUri('dummy:/test/uri')
+    player.OpenUri("dummy:/test/uri")
 
     assert core.tracklist.get_length().get() == 1
-    assert core.tracklist.get_tracks().get()[0].uri == 'dummy:/test/uri'
+    assert core.tracklist.get_tracks().get()[0].uri == "dummy:/test/uri"
 
 
 def test_open_uri_starts_playback_of_new_track_if_stopped(
-        backend, core, player):
-    backend.library.dummy_library = [Track(uri='dummy:/test/uri')]
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    backend, core, player
+):
+    backend.library.dummy_library = [Track(uri="dummy:/test/uri")]
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     assert core.playback.get_state().get() == STOPPED
 
-    player.OpenUri('dummy:/test/uri')
+    player.OpenUri("dummy:/test/uri")
 
     assert core.playback.get_state().get() == PLAYING
-    assert core.playback.get_current_track().get().uri == 'dummy:/test/uri'
+    assert core.playback.get_current_track().get().uri == "dummy:/test/uri"
 
 
-def test_open_uri_starts_playback_of_new_track_if_paused(
-        backend, core, player):
-    backend.library.dummy_library = [Track(uri='dummy:/test/uri')]
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+def test_open_uri_starts_playback_of_new_track_if_paused(backend, core, player):
+    backend.library.dummy_library = [Track(uri="dummy:/test/uri")]
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     core.playback.pause().get()
     assert core.playback.get_state().get() == PAUSED
-    assert core.playback.get_current_track().get().uri == 'dummy:a'
+    assert core.playback.get_current_track().get().uri == "dummy:a"
 
-    player.OpenUri('dummy:/test/uri')
+    player.OpenUri("dummy:/test/uri")
 
     assert core.playback.get_state().get() == PLAYING
-    assert core.playback.get_current_track().get().uri == 'dummy:/test/uri'
+    assert core.playback.get_current_track().get().uri == "dummy:/test/uri"
 
 
 def test_open_uri_starts_playback_of_new_track_if_playing(
-        backend, core, player):
-    backend.library.dummy_library = [Track(uri='dummy:/test/uri')]
-    core.tracklist.add([Track(uri='dummy:a'), Track(uri='dummy:b')])
+    backend, core, player
+):
+    backend.library.dummy_library = [Track(uri="dummy:/test/uri")]
+    core.tracklist.add([Track(uri="dummy:a"), Track(uri="dummy:b")])
     core.playback.play().get()
     assert core.playback.get_state().get() == PLAYING
-    assert core.playback.get_current_track().get().uri == 'dummy:a'
+    assert core.playback.get_current_track().get().uri == "dummy:a"
 
-    player.OpenUri('dummy:/test/uri')
+    player.OpenUri("dummy:/test/uri")
 
     assert core.playback.get_state().get() == PLAYING
-    assert core.playback.get_current_track().get().uri == 'dummy:/test/uri'
+    assert core.playback.get_current_track().get().uri == "dummy:/test/uri"
